@@ -122,12 +122,14 @@ basisExt (const long len, const long n, const FiniteField p, \
       cblas_dcopy(n, U[i-1], 1, U[i], 1);
       for (j = i-2; j >= 0; j--)
 	{
-	  catlas_daxpby(n, 1.0, U[j], 1, (double)(q[j] % q[i]), U[i], 1);
+	  cblas_dscal(n, (double)(q[j] % q[i]), U[i], 1);
+	  cblas_daxpy(n, 1.0, U[j], 1, U[i], 1);
 	  Dmod((double)q[i], U[i], 1, n, n);
 	}
       temp = (double)qinv[i]*(double)(q[i]-1);
       temp = fmod(temp, (double)q[i]);
-      catlas_daxpby(n, (double)qinv[i], R[i], 1, temp, U[i], 1);
+      cblas_dscal(n, temp, U[i], 1);
+      cblas_daxpy(n, (double)qinv[i], R[i], 1, U[i], 1);
       Dmod((double)q[i], U[i], 1, n, n);
     }
 
@@ -136,7 +138,8 @@ basisExt (const long len, const long n, const FiniteField p, \
   Dmod((double)p, RE, 1, n, n);
   for (i = len-2; i >= 0; i--)
     {
-      catlas_daxpby(n, 1.0, U[i], 1, (double)(q[i] % p), RE, 1);
+      cblas_dscal(n, (double)(q[i] % p), RE, 1);
+      cblas_daxpy(n, 1.0, U[i], 1,  RE, 1);
       Dmod((double)p, RE, 1, n, n);
     }
 
@@ -226,12 +229,14 @@ basisExtPos (const long len, const long n, const FiniteField p, \
       cblas_dcopy(n, U[i-1], 1, U[i], 1);
       for (j = i-2; j >= 0; j--)
 	{
-	  catlas_daxpby(n, 1.0, U[j], 1, (double)(q[j] % q[i]), U[i], 1);
+	  cblas_dscal(n, (double)(q[j] % q[i]), U[i], 1);
+	  cblas_daxpy(n, 1.0, U[j], 1, U[i], 1);
 	  Dmod((double)q[i], U[i], 1, n, n);
 	}
       temp = (double)qinv[i]*(double)(q[i]-1);
       temp = fmod(temp, (double)q[i]);
-      catlas_daxpby(n, (double)qinv[i], R[i], 1, temp, U[i], 1);
+      cblas_dscal(n, temp, U[i], 1);
+      cblas_daxpy(n, (double)qinv[i], R[i], 1, U[i], 1);
       Dmod((double)q[i], U[i], 1, n, n);
     }
 
@@ -240,7 +245,8 @@ basisExtPos (const long len, const long n, const FiniteField p, \
   Dmod((double)p, RE, 1, n, n);
   for (i = len-2; i >= 0; i--)
     {
-      catlas_daxpby(n, 1.0, U[i], 1, (double)(q[i] % p), RE, 1);
+      cblas_dscal(n, (double)(q[i] % p), RE, 1);
+      cblas_daxpy(n, 1.0, U[i], 1, RE, 1);
       Dmod((double)p, RE, 1, n, n);
     }
   for (i = 0; i < len; i++) { XFREE(U[i]); } { XFREE(U); }
